BEGIN TRANSACTION;
DROP TABLE IF EXISTS test_dirty;
DROP TABLE IF EXISTS test_dirty_ignored;
DROP TABLE IF EXISTS test_all;
DROP TABLE IF EXISTS test_all_ignored;
DROP TABLE IF EXISTS test_version;
DROP TABLE IF EXISTS test_version_ignored;
DROP TABLE IF EXISTS test_version_alt;
CREATE TABLE test_dirty (
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    col1 TEXT NOT NULL,
    col2 TEXT NOT NULL,
    col3 TEXT NOT NULL
);
CREATE TABLE test_dirty_ignored (
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    col1 TEXT NOT NULL,
    col2 TEXT NOT NULL,
    col3 TEXT NOT NULL
);
CREATE TABLE test_all (
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    col1 TEXT NOT NULL,
    col2 TEXT NOT NULL,
    col3 TEXT NOT NULL
);
CREATE TABLE test_all_ignored (
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    col1 TEXT NOT NULL,
    col2 TEXT NOT NULL,
    col3 TEXT NOT NULL
);
CREATE TABLE test_version (
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    col1 TEXT NOT NULL,
    col2 TEXT NOT NULL,
    version INTEGER NOT NULL default 0
);
CREATE TABLE test_version_ignored (
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    col1 TEXT NOT NULL,
    col2 TEXT NOT NULL,
    version INTEGER NOT NULL default 0
);
CREATE TABLE test_version_alt (
    id INTEGER PRIMARY KEY AUTOINCREMENT,
    col1 TEXT NOT NULL,
    col2 TEXT NOT NULL,
    myversion INTEGER NOT NULL default 0
);
COMMIT;
